@@ -1,19 +1,22 @@
 from speasy.core.datetime_range import DateTimeRange
+from .base_product import SpeasyProduct
 from typing import List
 from speasy.core import all_of_type, listify
+import pandas as pds
 
 
 def _all_are_datetime_ranges(dt_list):
     return all_of_type(dt_list, DateTimeRange)
 
 
-class TimeTable:
+class TimeTable(SpeasyProduct):
     """A TimeTable is basically a collection of DateTimeRange
 
     """
     __slots__ = ['name', 'meta', '_storage']
 
     def __init__(self, name: str, meta: dict = None, dt_ranges: List[DateTimeRange] = None):
+        super().__init__()
         self.name = name
         self.meta = meta or {}
         self._storage = dt_ranges or []
@@ -26,6 +29,9 @@ class TimeTable:
     def __len__(self):
         return len(self._storage)
 
+    def __iter__(self):
+        return self._storage.__iter__()
+
     def append(self, dt_range: DateTimeRange or List[DateTimeRange]):
         dt_range = listify(dt_range)
         if not _all_are_datetime_ranges(dt_range):
@@ -40,5 +46,8 @@ class TimeTable:
     def pop(self, index=-1):
         return self._storage.pop(index)
 
+    def to_dataframe(self) -> pds.DataFrame:
+        return pds.DataFrame(columns=['start_time', 'stop_time'], data=[(*r,) for r in self])
+
     def __repr__(self):
         return f"""<TimeTable: {self.name}>"""
