@@ -6,6 +6,9 @@ from datetime import datetime
 from enum import Enum
 from typing import Dict, List, Optional, Union
 
+from ._impl import is_private, is_public
+from .inventory import to_xmlid
+from .utils import get_parameter_args
 from ...config import amda as amda_cfg
 from ...core import AllowedKwargs, make_utc_datetime
 from ...core.cache import CACHE_ALLOWED_KWARGS, Cacheable, CacheCall
@@ -20,13 +23,18 @@ from ...products.catalog import Catalog
 from ...products.dataset import Dataset
 from ...products.timetable import TimeTable
 from ...products.variable import SpeasyVariable
-from ._impl import is_private, is_public
-from .inventory import to_xmlid
-from .utils import get_parameter_args
 
 log = logging.getLogger(__name__)
 
 
+def _amda_cache_entry_name(prefix: str, product: str, start_time: str, **kwargs):
+    output_format: str = kwargs.get('output_format', 'csv')
+    if output_format.lower() == 'cdf_istp':
+        return f"{prefix}/{product}-cdf_istp/{start_time}"
+    else:
+        return f"{prefix}/{product}/{start_time}"
+
+
 class ProductType(Enum):
     """Enumeration of the type of products available in AMDA_Webservice.
     """
@@ -313,12 +321,13 @@ class AMDA_Webservice(DataProvider):
         catalog_id = to_xmlid(catalog_id)
         return self._impl.dl_user_catalog(catalog_id=catalog_id)
 
-    @AllowedKwargs(PROXY_ALLOWED_KWARGS + CACHE_ALLOWED_KWARGS + GET_DATA_ALLOWED_KWARGS)
+    @AllowedKwargs(PROXY_ALLOWED_KWARGS + CACHE_ALLOWED_KWARGS + GET_DATA_ALLOWED_KWARGS + ['output_format'])
     @ParameterRangeCheck()
-    @Cacheable(prefix="amda", version=product_version, fragment_hours=lambda x: 12)
+    @Cacheable(prefix="amda", version=product_version, fragment_hours=lambda x: 12, entry_name=_amda_cache_entry_name)
     @Proxyfiable(GetProduct, get_parameter_args)
     def get_parameter(self, product, start_time, stop_time,
-                      extra_http_headers: Dict or None = None, **kwargs) -> Optional[SpeasyVariable]:
+                      extra_http_headers: Dict or None = None, output_format: str or None = None, **kwargs) -> Optional[
+        SpeasyVariable]:
         """Get parameter data.
 
         Parameters
@@ -331,6 +340,8 @@ class AMDA_Webservice(DataProvider):
             desired data stop time
         extra_http_headers: dict
             reserved for internal use
+        output_format: str
+            request output format in case of success, allowed values are ASCII and CDF_ISTP
 
         Returns
         -------
@@ -351,7 +362,8 @@ class AMDA_Webservice(DataProvider):
         """
         log.debug(f'Get data: product = {product}, data start time = {start_time}, data stop time = {stop_time}')
         return self._impl.dl_parameter(start_time=start_time, stop_time=stop_time, parameter_id=product,
-                                       extra_http_headers=extra_http_headers)
+                                       extra_http_headers=extra_http_headers,
+                                       output_format=output_format or amda_cfg.output_format())
 
     def get_dataset(self, dataset_id: str or DatasetIndex, start: str or datetime, stop: str or datetime,
                     **kwargs) -> Dataset or None:
@@ -395,7 +407,8 @@ class AMDA_Webservice(DataProvider):
         meta = {k: v for k, v in self.flat_inventory.datasets[dataset_id].__dict__.items() if
                 not isinstance(v, SpeasyIndex)}
         parameters = self.list_parameters(dataset_id)
-        return Dataset(name=name, variables={p.name: self.get_parameter(p, start, stop, **kwargs) for p in parameters},
+        return Dataset(name=name,
+                       variables={p.name: self.get_parameter(p, start, stop, **kwargs) for p in parameters},
                        meta=meta)
 
     @CacheCall(cache_retention=amda_cfg.user_cache_retention())
@@ -617,7 +630,8 @@ class AMDA_Webservice(DataProvider):
         """
         return list(filter(is_public, self.flat_inventory.datasets.values()))
 
-    def _find_parent_dataset(self, product_id: str or DatasetIndex or ParameterIndex or ComponentIndex) -> Optional[str]:
+    def _find_parent_dataset(self, product_id: str or DatasetIndex or ParameterIndex or ComponentIndex) -> Optional[
+        str]:
 
         product_id = to_xmlid(product_id)
         product_type = self.product_type(product_id)
